/*
 * aTunes 1.13.3
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.panels;

import java.awt.BorderLayout;
import java.awt.Cursor;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.WindowConstants;

import net.sourceforge.atunes.gui.Fonts;

import org.jdesktop.swingx.border.DropShadowBorder;

/**
 * The Class FilePropertiesPanel.
 * 
 * @author fleax
 */
public class FilePropertiesPanel extends JPanel {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 6097305595858691246L;

    /** The song panel. */
    private JPanel songPanel;

    /** The picture label. */
    private JLabel pictureLabel;

    /** The file name label. */
    private JLabel fileNameLabel;

    /** The song label. */
    private JLabel songLabel;

    /** The track label. */
    private JLabel trackLabel;
    
    /** The disc number */
    private JLabel discNumberLabel;

    /** The year label. */
    private JLabel yearLabel;

    /** The genre label. */
    private JLabel genreLabel;

    /** The bitrate label. */
    private JLabel bitrateLabel;

    /** The frequency label. */
    private JLabel frequencyLabel;

    /**
     * Instantiates a new file properties panel.
     */
    public FilePropertiesPanel() {
        super(new BorderLayout());
        addContent();
    }

    /**
     * The main method.
     * 
     * @param args
     *            the arguments
     */
    public static void main(String[] args) {
        JFrame frame = new JFrame();
        frame.setSize(600, 300);
        frame.add(new FilePropertiesPanel());
        frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        frame.setVisible(true);
    }

    /**
     * Adds the content.
     */
    private void addContent() {
        getSongPanel().setVisible(false);
        getPictureLabel().setVisible(false);
        add(getSongPanel(), BorderLayout.CENTER);
    }

    /**
     * Gets the bitrate label.
     * 
     * @return the bitrate label
     */
    public JLabel getBitrateLabel() {
        return bitrateLabel;
    }

    /**
     * Gets the file name label.
     * 
     * @return the file name label
     */
    public JLabel getFileNameLabel() {
        return fileNameLabel;
    }

    /**
     * Gets the frequency label.
     * 
     * @return the frequency label
     */
    public JLabel getFrequencyLabel() {
        return frequencyLabel;
    }

    /**
     * Gets the genre label.
     * 
     * @return the genre label
     */
    public JLabel getGenreLabel() {
        return genreLabel;
    }

    /**
     * Gets the picture label.
     * 
     * @return the picture label
     */
    public JLabel getPictureLabel() {
        return pictureLabel;
    }

    /**
     * Gets the song label.
     * 
     * @return the song label
     */
    public JLabel getSongLabel() {
        return songLabel;
    }

    /**
     * Gets the song panel.
     * 
     * @return the song panel
     */
    public JPanel getSongPanel() {
        if (songPanel == null) {
            songPanel = new JPanel(new GridBagLayout());
            pictureLabel = new JLabel();
            pictureLabel.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
            pictureLabel.setBorder(new DropShadowBorder());
            GridBagConstraints c = new GridBagConstraints();
            c.gridx = 0;
            c.gridy = 0;
            c.gridheight = 7;
            c.insets = new Insets(5, 10, 5, 5);
            songPanel.add(pictureLabel, c);
            c.gridx = 1;
            c.gridy = 0;
            c.gridwidth = 3;
            c.gridheight = 1;
            c.weightx = 1;
            c.weighty = 1;
            c.fill = GridBagConstraints.BOTH;
            c.insets = new Insets(5, 10, 0, 10);
            songLabel = new JLabel();
            songLabel.setFont(Fonts.SMALL_FONT);
            songLabel.setHorizontalTextPosition(SwingConstants.LEFT);
            songPanel.add(songLabel, c);
            c.gridy = 1;
            c.insets = new Insets(0, 10, 0, 10);
            fileNameLabel = new JLabel();
            fileNameLabel.setFont(Fonts.SMALL_FONT);
            songPanel.add(fileNameLabel, c);
            c.gridy = 2;
            c.gridwidth = 1;
            c.insets = new Insets(0, 10, 0, 5);
            trackLabel = new JLabel();
            trackLabel.setFont(Fonts.SMALL_FONT);
            songPanel.add(trackLabel, c);
            c.gridy = 3;
            discNumberLabel = new JLabel();
            discNumberLabel.setFont(Fonts.SMALL_FONT);
            songPanel.add(discNumberLabel, c);
            c.gridy = 4;
            yearLabel = new JLabel();
            yearLabel.setFont(Fonts.SMALL_FONT);
            c.insets = new Insets(0, 10, 5, 10);
            songPanel.add(yearLabel, c);
            
            c.gridx = 2;
            c.gridy = 2;
            genreLabel = new JLabel();
            genreLabel.setFont(Fonts.SMALL_FONT);
            c.insets = new Insets(0, 5, 0, 5);
            songPanel.add(genreLabel, c);

            c.gridy = 3;
            bitrateLabel = new JLabel();
            bitrateLabel.setFont(Fonts.SMALL_FONT);
            songPanel.add(bitrateLabel, c);
            frequencyLabel = new JLabel();
            frequencyLabel.setFont(Fonts.SMALL_FONT);
            c.gridy = 4;
            songPanel.add(frequencyLabel, c);
        }
        return songPanel;
    }

    /**
     * Gets the track label.
     * 
     * @return the track label
     */
    public JLabel getTrackLabel() {
        return trackLabel;
    }

    /**
     * Gets the year label.
     * 
     * @return the year label
     */
    public JLabel getYearLabel() {
        return yearLabel;
    }

    /**
     * @return the discNumberLabel
     */
    public JLabel getDiscNumberLabel() {
        return discNumberLabel;
    }

}
