/*
 * aTunes 1.13.3
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.dialogs.SearchDialog;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.modules.desktop.DesktopHandler;
import net.sourceforge.atunes.kernel.modules.internetsearch.Search;
import net.sourceforge.atunes.kernel.modules.internetsearch.SearchFactory;
import net.sourceforge.atunes.kernel.modules.navigator.NavigationViews;
import net.sourceforge.atunes.kernel.modules.navigator.RepositoryNavigationView;
import net.sourceforge.atunes.kernel.modules.repository.model.Artist;
import net.sourceforge.atunes.kernel.modules.state.ApplicationState;
import net.sourceforge.atunes.kernel.modules.visual.VisualHandler;
import net.sourceforge.atunes.utils.LanguageTool;

public class SearchArtistAction extends AbstractAction {

    private static final long serialVersionUID = -4695334457704311336L;

    SearchArtistAction() {
        super(LanguageTool.getString("SEARCH_ARTIST"), ImageLoader.SEARCH_ARTIST);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("SEARCH_ARTIST"));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        Search defaultSearch = SearchFactory.getSearchForName(ApplicationState.getInstance().getDefaultSearch());
        if (defaultSearch != null) {
            if (ControllerProxy.getInstance().getNavigationController().getPopupMenuCaller() == NavigationViews.getView(RepositoryNavigationView.class).getTree()) {
                TreePath path = NavigationViews.getView(RepositoryNavigationView.class).getTree().getSelectionPath();
                if (((DefaultMutableTreeNode) path.getLastPathComponent()).getUserObject() instanceof Artist) {
                    Artist a = (Artist) ((DefaultMutableTreeNode) path.getLastPathComponent()).getUserObject();
                    DesktopHandler.getInstance().openSearch(defaultSearch, a.getName());
                }
            }
        } else {
            SearchDialog dialog = VisualHandler.getInstance().getSearchDialog();
            Search selectedSearch = ControllerProxy.getInstance().getNavigationController().openSearchDialog(dialog, false);
            if (selectedSearch != null) {
                ApplicationState.getInstance().setDefaultSearch(selectedSearch.toString());
            }
        }
    }

}
